numpy.poly1d
============

.. currentmodule:: numpy

.. autoclass:: poly1d

   

   .. HACK
      .. autosummary::
         :toctree:
      
         poly1d.__init__
         poly1d.deriv
         poly1d.integ



   

